@@ -20,7 +20,12 @@ class AwsSessionFactory:
         else:
             start_msg = f'{start_msg} using AWS auth-chain'
         logger.info(f'{start_msg}...')
-        session = boto3.Session(**session_data)
+        try:
+            session = boto3.Session(**session_data)
+        except ClientError as ex:
+            raise DragoneyeException(f'An exception happened while trying to create session: {str(ex)}', ex.response['Error']['Message'])
+        except Exception as ex:
+            raise DragoneyeException(f'An unknown exception happened while trying to create session: {str(ex)}', str(ex))
         AwsSessionFactory.test_connectivity(session)
         logger.info('Session was created successfully')
         return session
@@ -29,20 +34,25 @@ class AwsSessionFactory:
     def get_session_using_assume_role(role_arn: str, external_id: str, region: Optional[str] = None, session_duration: int = 3600):
         role_session_name = "DragoneyeSession"
         logger.info('Will try to assume role using ARN: {} and external id {}...'.format(role_arn, external_id))
-        client = boto3.client('sts')
-        response = client.assume_role(RoleArn=role_arn,
-                                      RoleSessionName=role_session_name,
-                                      DurationSeconds=session_duration,
-                                      ExternalId=external_id)
-        credentials = response['Credentials']
-        session_data = {
-            "aws_access_key_id": credentials['AccessKeyId'],
-            "aws_secret_access_key": credentials['SecretAccessKey'],
-            "aws_session_token": credentials['SessionToken']
-        }
-        if region:
-            session_data['region_name'] = region
-        session = boto3.Session(**session_data)
+        try:
+            client = boto3.client('sts')
+            response = client.assume_role(RoleArn=role_arn,
+                                          RoleSessionName=role_session_name,
+                                          DurationSeconds=session_duration,
+                                          ExternalId=external_id)
+            credentials = response['Credentials']
+            session_data = {
+                "aws_access_key_id": credentials['AccessKeyId'],
+                "aws_secret_access_key": credentials['SecretAccessKey'],
+                "aws_session_token": credentials['SessionToken']
+            }
+            if region:
+                session_data['region_name'] = region
+            session = boto3.Session(**session_data)
+        except ClientError as ex:
+            raise DragoneyeException(f'An exception happened while trying to assume role: {str(ex)}', ex.response['Error']['Message'])
+        except Exception as ex:
+            raise DragoneyeException(f'An unknown exception happened while trying to assume role: {str(ex)}', str(ex))
         AwsSessionFactory.test_connectivity(session)
         logger.info('Session was created successfully')
         return session
@@ -55,5 +65,5 @@ class AwsSessionFactory:
         except ClientError as ex:
             if "InvalidClientTokenId" in str(ex):
                 raise DragoneyeException('sts.get_caller_identity failed with InvalidClientTokenId. '
-                                         'Likely cause is no AWS credentials are set', ex)
-            raise DragoneyeException('Unknown exception when trying to call sts.get_caller_identity: {}'.format(ex), ex)
+                                         'Likely cause is no AWS credentials are set', str(ex))
+            raise DragoneyeException('Unknown exception when trying to call sts.get_caller_identity: {}'.format(ex), str(ex))
