@@ -6,13 +6,15 @@ from typing import Optional
 import requests
 from dragoneye.utils.app_logger import logger
 from dragoneye.dragoneye_exception import DragoneyeException
+from dragoneye.utils.misc_utils import invoke_get_request
 from dragoneye.utils.value_validator import validate_uuid
 
 
 class AzureAuthorizer:
 
     @staticmethod
-    def get_authorization_token(tenant_id: Optional[str] = None,
+    def get_authorization_token(subscription_id: str,
+                                tenant_id: Optional[str] = None,
                                 client_id: Optional[str] = None,
                                 client_secret: Optional[str] = None) -> str:
         """
@@ -23,13 +25,17 @@ class AzureAuthorizer:
         Otherwise, it will attempt to generate a token from your CLI credentials, using
         `az account get-access-token <https://docs.microsoft.com/en-us/cli/azure/account?view=azure-cli-latest#az_account_get_access_token>`__
         """
+        validate_uuid(subscription_id, 'Invalid subscription id')
         if not (client_id and client_secret and tenant_id):
             token = AzureAuthorizer._get_token_from_az_cli()
         else:
             token = AzureAuthorizer._get_token_from_credentials(tenant_id, client_id, client_secret)
 
+        auth_token = f'Bearer {token}'
+        AzureAuthorizer.test_connectivity(subscription_id, auth_token)
+
         logger.info('JWT bearer token generated successfully')
-        return f'Bearer {token}'
+        return auth_token
 
     @staticmethod
     def _get_token_from_credentials(tenant_id: str, client_id: str, client_secret: str) -> str:
@@ -71,3 +77,14 @@ class AzureAuthorizer:
             ind = output.rindex('}') + 1
             output = output[:ind]
             return json.loads(output)['accessToken']
+
+    @staticmethod
+    def test_connectivity(subscription_id, token):
+        headers = {
+            'Authorization': token
+        }
+        url = f'https://management.azure.com/subscriptions/{subscription_id}/resourcegroups?api-version=2020-09-01'
+        response = invoke_get_request(url, headers)
+        if response.status_code != 200:
+            raise DragoneyeException(f'Failed to authenticate. status code: {response.status_code}\n'
+                                     f'Reason: {response.text}', response.text)
